Boyfriend of ‘Mob Wives’ star will sue Brooklyn club - NY Daily News
Description: The boyfriend of ‘Mob Wives’ star Natalie Guercio will sue a Brooklyn club where he was attacked by a man with a box cutter.

# Boyfriend of ‘Mob Wives’ star Natalie Guercio will sue Brooklyn club where he was attacked

## London Rene is claiming Club Output provided 'inept' and ‘incompetent’ security that was unable to keep patrons safe on Dec. 28 when he was attacked by a man with a box cutter outside the Williamsburg nightspot. The lawsuit will be filed Thursday and seeks unspecified monetary damages for Rene’s physical and emotional scars.

BY John Marzulli
NEW YORK DAILY NEWS
Wednesday, January 14, 2015, 7:09 PM

- A
- A
- A

Share this URL

Kevin C. Downs/for New York Daily News London Rene and 'Mob Wives' star Natalie Guercio pose in the office of their lawyer, Scott Rynecki. The couple was outside a Brooklyn club on Dec. 28 when a man with a box cutter attacked Rene.

The boyfriend of sexy “Mob Wives” star Natalie Guercio is suing the Brooklyn club where he was brutally slashed by a box cutter-wielding assailant, the Daily News has learned.

London Rene is alleging Club Output's "inept" and "incompetent" security was negligent in failing to provide proper safety for its patrons on Dec. 28 when he was attacked outside the Williamsburg nightspot.

Rene's lawyer Scott Rynecki said there was "little or no security" watching over the club, which has a capacity of 600-persons.

The suit, which will be filed Thursday in Brooklyn Supreme Court, seeks unspecified monetary damages for Rene's physical and emotional scars. The court papers also name the security guard firm hired by the club.

"When I look in the mirror I'm angry," Rene, 37, said Wednesday. "I'm scarred for life; the scars are going to be there until the day I die."

Kevin C. Downs/for New York Daily News
Rene seeks unspecified monetary damages for his physical and emotional scars. He plans to file the lawsuit Thursday.
Kevin C. Downs/for New York Daily News
London Rene suffered scars from the attack.
Previous Next

Enlarge

The alleged slasher, Rodolfo Lopez, fled the scene and later surrendered to the NYPD.

Rene's face and torso were cut in the attack. Guercio, whose family owns a funeral home in Philadelphia where mobsters and their families were laid out, witnessed the slashing but she was not hurt.

"Any one of us could have been a victim," she said.

There was no listed phone number for the club.

jmarzulli@nydailynews.com

Related Stories
  NYPD identifies suspect in 'Mob Wives' slashing

  Alleged ‘Mob Wives’ boyfriend slasher turns himself in

##### Comments

Post A Comment [ Discussion Guidelines]

To Post Comments Sign In

##### Editor's Picks

### Lawmakers want to improve a hospital in Washington Heights

Medical center could burnish its credentials by beefing up its emergency room staff and expanding patient access to urgent care.

### VIDEO: Brooklyn gym teacher kisses former student

A video has surfaced showing a Brooklyn gym teacher in a pizza shop kissing a student who graduated last year.

### City preservationists target former Brooklyn police precinct

THE CASE for a graffiti-scarred former police stationhouse in Brooklyn could be headed to court.

### Boyfriend of ‘Mob Wives’ star will sue Brooklyn club

The boyfriend of ‘Mob Wives’ star Natalie Guercio will sue a Brooklyn club where he was attacked by a man with a box cutter.

### Immigrant-owned restaurants in the South Bronx are getting a

Immigrant-owned restaurants in the Bronx are getting a boost.

##### FROM AROUND THE WEB

##### Editor's Picks

### Dog killer sought in Brooklyn

A witness spotted a cruel motorist chuck an injured pit bull from a car in Crown Heights — and then back over the poor pooch, advocates say.

### Plan for Rockaway vendors on hold

A plan to allow vendors at several locations along the beaches in Rockaway is on hold

### Bronx borough president’s ex-aide now a foe at the polls

First, this longtime soldier to Bronx Borough President Ruben Diaz Jr. sued her longtime superior for her dismissal.

### First Rockaway Parks Administrator retires

After 32 years at the New York City Parks Department, Jill Weber thought she had seen it all - until Hurricane Sandy hit.

### Artist takes over Queens billboard

A Brooklyn artist has taken over a vacant Queens billboard with the help of nonprofit 14x48.

### Queens drummer gets over Oscars 'Birdman' disqualification

One of the biggest Oscar snubs of the year hits home not in Tinseltown, but Queens — over potential best picture “Birdman.”

### Developer must again revise plans for East Harlem complex

It’s back to the drawing board for a building that has raised the ire of East Harlem residents ever since it was unveiled last year.

### Accused accomplice in Bronx cop-shooting denies involvement

The alleged accomplice of the accused shooter of two cops after a Bronx bodega robbery had nothing to do with it, his lawyer said Monday.

### Bronx produce workers threaten strike over $5 raise bid

Workers at a famed Bronx market that supplies fruits and vegetables to most of the city’s restaurants and grocers may walk off the job.

### Mark-Viverito tweets condolences for Puerto Rican activist

City Council Speaker Melissa Mark-Viverito tweeted her condolences on the death of a Puerto Rican nationalist.

### The CUNY Value

CUNY is today’s best value in the higher education marketplace. Our low costs make it possible for seven in 10 full-time undergraduates to attend college tuition-free, fully covered by financial aid and the American Opportunity Tax Credit, and for eight in 10 to graduate free from federal education debt. That’s freedom. That’s CUNY Value.

Find Out More

###

BEST CITY APP

IN THE WORLD!

App Store Android
FREE

### Daily News Pix Brooklyn

From Coney Island to the Brooklyn Bridge, the Daily News has decades of classic photos of Brooklyn.

Buy a Print

##### New York Video